@@ -18,20 +18,27 @@
 //! let tz: chrono_tz::Tz = tz_str.parse()?;
 //! ```
 
-#[cfg(target_os = "linux")]
-mod tz_linux;
-#[cfg(target_os = "linux")]
-use tz_linux as platform;
-
-#[cfg(target_os = "windows")]
-mod tz_windows;
-#[cfg(target_os = "windows")]
-use tz_windows as platform;
-
-#[cfg(target_os = "macos")]
-mod tz_macos;
-#[cfg(target_os = "macos")]
-use tz_macos as platform;
+#[cfg_attr(target_os = "linux", path = "tz_linux.rs")]
+#[cfg_attr(target_os = "windows", path = "tz_windows.rs")]
+#[cfg_attr(any(target_os = "macos", target_os = "ios"), path = "tz_macos.rs")]
+#[cfg_attr(
+    all(target_arch = "wasm32", not(target_os = "wasi")),
+    path = "tz_wasm32.rs"
+)]
+#[cfg_attr(
+    any(target_os = "freebsd", target_os = "dragonfly"),
+    path = "tz_freebsd.rs"
+)]
+#[cfg_attr(
+    any(target_os = "netbsd", target_os = "openbsd"),
+    path = "tz_netbsd.rs"
+)]
+#[cfg_attr(
+    any(target_os = "illumos", target_os = "solaris"),
+    path = "tz_illumos.rs"
+)]
+#[cfg_attr(target_os = "android", path = "tz_android.rs")]
+mod platform;
 
 /// Error types
 #[derive(Debug)]
@@ -44,18 +51,23 @@ pub enum GetTimezoneError {
     OsError,
 }
 
-impl std::error::Error for GetTimezoneError {}
+impl std::error::Error for GetTimezoneError {
+    fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
+        match self {
+            GetTimezoneError::FailedParsingString => None,
+            GetTimezoneError::IoError(err) => Some(err),
+            GetTimezoneError::OsError => None,
+        }
+    }
+}
 
 impl std::fmt::Display for GetTimezoneError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> Result<(), std::fmt::Error> {
-        use GetTimezoneError::*;
-        let descr = match self {
-            FailedParsingString => "GetTimezoneError::FailedParsingString",
-            IoError(_) => "GetTimezoneError::IoError(_)",
-            OsError => "OsError",
-        };
-
-        write!(f, "{}", descr)
+        f.write_str(match self {
+            GetTimezoneError::FailedParsingString => "GetTimezoneError::FailedParsingString",
+            GetTimezoneError::IoError(err) => return err.fmt(f),
+            GetTimezoneError::OsError => "OsError",
+        })
     }
 }
 
@@ -69,6 +81,7 @@ impl std::convert::From<std::io::Error> for GetTimezoneError {
 ///
 /// See the module-level documentatation for a usage example and more details
 /// about this function.
+#[inline]
 pub fn get_timezone() -> std::result::Result<String, crate::GetTimezoneError> {
     platform::get_timezone_inner()
 }
